#
# spec file for package libreadline-java
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global make make
Name:           libreadline-java
Version:        0.8.3
Release:        3.1
Summary:        Java Wrapper for the EditLine Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Java
URL:            https://github.com/aclemons/java-readline
Source0:        https://github.com/aclemons/java-readline/releases/download/v%{version}/%{name}-%{version}-src.tar.gz
Source1:        baselibs.conf
Patch0:         libreadline-java-ncurses.patch
Patch1:         libreadline-java-libdir.patch
Patch3:         libreadline-java-0.8.0-jdk10.patch
Patch4:         libreadline-java-gcc14.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
BuildRequires:  libedit-devel >= 2.9
BuildRequires:  ncurses-devel
BuildRequires:  zlib-devel
Requires:       java
Requires:       libedit >= 2.9
Provides:       gnu.readline
Provides:       java_readline

%description
libreadline-java provides Java bindings for libedit though a JNI
wrapper.

%package javadoc
Summary:        Javadoc for libreadline-java
Group:          Development/Libraries/Java

%description javadoc
libreadline-java provides Java bindings for libedit though a JNI
wrapper. This package contains the javadoc documentation for it.

%prep
%setup -q
%patch -P 0
%patch -P 1
%patch -P 3 -p1
%patch -P 4 -p1
find . -name "*.jar" -exec rm -f {} \;
sed -i 's|@LIBDIR@|%{_libdir}|' src/org/gnu/readline/Readline.java

%build
export JAVA_HOME=%{java_home}
export PATH=$JAVA_HOME/bin:$JAVA_HOME/jre/bin:$PATH
%make CFLAGS="%{optflags} -fPIC -DPOSIX" T_LIBS=JavaEditline -j1
%make apidoc -j1

# fix debuginfo package
rm -f org test
for dir in org test
do
  ln -s src/$dir
done

%install
mkdir -p %{buildroot}%{_libdir}/%{name}
install -m 644 %{name}.jar \
  %{buildroot}%{_libdir}/%{name}/%{name}.jar
install -m 755 libJavaEditline.so %{buildroot}%{_libdir}/%{name}

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -a api/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files
%license COPYING.LIB
%doc NEWS README README.1st VERSION
%dir %{_libdir}/%{name}
%attr(-,root,root) %{_libdir}/%{name}/*

%files javadoc
%doc %{_javadocdir}/%{name}

%changelog
* Mon May  6 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * libreadline-java-gcc14.patch
    + cast out constness and fix build with gcc14
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon May  9 2022 David Anes <david.anes@suse.com>
- Version bump to release 0.8.3:
  * added support for building with newer JDKs.
- Updated patches:
  * Rebased: libreadline-java-0.8.0-jdk10.patch
  * Removed: libreadline-java-0.8.0-sourcetarget.patch
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * libreadline-java-0.8.0-sourcetarget.patch
    + Build with source/target levels 8
* Fri Aug  3 2018 tchvatal@suse.com
- Version bump to 0.8.2:
  * bugfix: using tab completion would crash the virtual machine
  * getVar()/setVar() (Bernhard)
  * unicode support (Andrew)
  * added bats test case and running on travis ci (Andrew)
  * various build fixes (Andrew)
- Update URL/Source to point to current location
- Refresh patches:
  * libreadline-java-0.8.0-jdk10.patch
  * libreadline-java-0.8.0-sourcetarget.patch
  * libreadline-java-ncurses.patch
- Remove upstream merged:
  * libreadline-java-0.8.0-missing-return-type.patch
* Mon Dec 18 2017 fstrba@suse.com
- Added patch:
  * libreadline-java-0.8.0-jdk10.patch
  - Allow building with jdk10 that does not have javah
  * libreadline-java-0.8.0-sourcetarget.patch
  - Build with source and target level 1.6
- Run fdupes on documentation
* Mon Sep 18 2017 fstrba@suse.com
- Removed patch:
  * libreadline-java-0.8.0-doclint.patch
  - Not needed since we disabled globally doclint by default
* Fri Sep  8 2017 fstrba@suse.com
- Added patch:
  * libreadline-java-0.8.0-doclint.patch
  - Fix build with jdk9 whose javadoc is more picky
* Fri Jun  9 2017 tchvatal@suse.com
- Require java 1.6.0 or newer to build as gcj won't compile us
* Tue Jul  8 2014 tchvatal@suse.com
- Cleanup bit more.
* Fri Jun 27 2014 tchvatal@suse.com
- Fix build on sle11
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner.
* Fri Sep 13 2013 mvyskocil@suse.com
- add javapackages-tools to buildrequires
* Wed Jun 20 2012 mvyskocil@suse.cz
- do not build with gcc java
- use libedit instead of gnu readline (licensing issues)
* Thu Jan 12 2012 andreas.stieger@gmx.de
- remove libreadline-java-java14compat.patch
  ( -C -ftarget=1.4 not supported by current javac )
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Jul 31 2008 anosek@suse.cz
- added %%{_javadocdir} to the %%files section
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jan 23 2008 mvyskocil@suse.cz
- fixed beta build
* Tue May 29 2007 dbornkessel@suse.de
- added gjdoc and fastjar to BuildRequires
* Wed May  2 2007 dbornkessel@suse.de
- added unzip to BuildRequires
* Wed Feb 14 2007 dbornkessel@suse.de
- added missing return type where missing (Bug #237944)
* Thu Dec 14 2006 jsmeix@suse.de
- Removed xml-commons-apis from BuildRequires because xerces-j2
  already provides xml-commons-apis but xerces-j2 would be
  deinstalled when rpm installs xml-commons-apis after xerces-j2
  (which is rpm standard behaviour in this case) but without
  xerces-j2 the RPM capabilities jaxp_parser_impl and
  xml-commons-resolver are no longer provided in the
  installed system.
* Tue Sep 26 2006 skh@suse.de
- don't use icecream
- use -source 1.4 and -target 1.4 for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 25 2005 jsmeix@suse.de
- Replaced {_jnidir} by {_jnidir}-ext
* Wed Aug 17 2005 uli@suse.de
- fixed to build on lib64 archs
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 0.8.0 from JPackage.org
* Wed Jul 13 2005 uli@suse.de
- lib64tified (fixes s390x)
* Thu Nov 18 2004 ro@suse.de
- fixed file list
* Wed Sep 15 2004 skh@suse.de
- Fix Requires (remove fixed dependency on readline 4.3 and enable rpm
  dependency check)
* Wed Sep  8 2004 skh@suse.de
- Fix PreRequire
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 0.8.0 (JPackage 1.5)
